/** *****************************************************
 * Copyright (C) HRider in motion S.L.
 *
 * This file is part of HRider.
 *
 * HRider can not be copied and/or distributed without the express
 * permission of HRider in motion S.L.
 ****************************************************** */
package net.hrider.api.usecases;

import java.util.List;
import net.hrider.api.client.ApiException;
import net.hrider.api.model.Employee;
import net.hrider.api.model.EmployeesCollection;
import net.hrider.api.model.Link;

/**
 * Use case queries with pagination.
 * 
 * @author drh (dani@hrider.net)
 */
public class Pagination extends AbstractUseCase {

    
    @Override
    public void doRun() throws ApiException {
        // create employees 
        Link employeesLink = getDummyCompany().getLinks().getEmployees();
        service.create(employeesLink, buildEmployee("EMP1", "Employee 1", "emp1@acme.com"));
        service.create(employeesLink, buildEmployee("EMP2", "Employee 2", "emp2@acme.com"));
        service.create(employeesLink, buildEmployee("EMP3", "Employee 3", "emp2@acme.com"));        
        
        // query with page size = 2
        Link link = getDummyCompany().getLinks().getEmployees().addQueryParam("pageSize", "2");
        EmployeesCollection collection = service.get(EmployeesCollection.class, link);
        int page = 1;
        printPage(page++, collection.getEmbedded().getEmployees());
        while (collection.getLinks().getNext() != null) {
            collection = service.get(EmployeesCollection.class, collection.getLinks().getNext());
            printPage(page++, collection.getEmbedded().getEmployees());
        }
    }

    public static void main(String[] args) {
        (new Pagination()).run();
    }
    
    // private methods *********************************************************
    
    private void printPage(int page, List<Employee> employees) {
        System.out.println("Page: " + page);
        printEmployees(employees);
    }
    
}
